# Translation API

::: pretok.translation.Translator
    options:
      show_source: true

::: pretok.translation.TranslationResult

::: pretok.translation.TranslationError

::: pretok.translation.llm.LLMTranslator

::: pretok.translation.factory.create_translator
